@@ -52,10 +52,19 @@ static int get_image( mlt_frame frame, uint8_t **image, mlt_image_format *format
 
 	// Update the frame
 	mlt_properties properties = mlt_frame_properties( frame );
-	mlt_properties_set_data( properties, "image", new_image, size, mlt_pool_release, NULL );
+	mlt_frame_set_image( frame, new_image, size, mlt_pool_release );
 	memcpy( new_image, *image, size );
 	mlt_properties_set( properties, "progressive", mlt_properties_get( MLT_FRAME_PROPERTIES(nested_frame), "progressive" ) );
 	*image = new_image;
+	
+	// Copy the alpha channel
+	uint8_t *alpha = mlt_properties_get_data( MLT_FRAME_PROPERTIES( nested_frame ), "alpha", &size );
+	if ( alpha && size > 0 )
+	{
+		new_image = mlt_pool_alloc( size );
+		memcpy( new_image, alpha, size );
+		mlt_frame_set_alpha( frame, new_image, size, mlt_pool_release );
+	}
 
 	return result;
 }
@@ -64,21 +73,9 @@ static int get_audio( mlt_frame frame, void **buffer, mlt_audio_format *format,
 {
 	mlt_frame nested_frame = mlt_frame_pop_audio( frame );
 	int result = mlt_frame_get_audio( nested_frame, buffer, format, frequency, channels, samples );
-	int size = *channels * *samples;
-
-	switch ( *format )
-	{
-		case mlt_audio_s16:
-			size *= sizeof( int16_t );
-			break;
-		case mlt_audio_s32:
-			size *= sizeof( int32_t );
-		case mlt_audio_float:
-			size *= sizeof( float );
-		default:
-			mlt_log_error( NULL, "[producer consumer] Invalid audio format\n" );
-	}
+	int size = mlt_audio_format_size( *format, *samples, *channels );
 	int16_t *new_buffer = mlt_pool_alloc( size );
+
 	mlt_properties_set_data( MLT_FRAME_PROPERTIES( frame ), "audio", new_buffer, size, mlt_pool_release, NULL );
 	memcpy( new_buffer, *buffer, size );
 	*buffer = new_buffer;
@@ -209,7 +206,7 @@ static void producer_close( mlt_producer this )
 
 mlt_producer producer_consumer_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg )
 {
-	mlt_producer this = mlt_producer_new( );
+	mlt_producer this = mlt_producer_new( profile );
 
 	// Encapsulate the real producer
 	mlt_profile temp_profile = mlt_profile_init( NULL );
