@@ -27,9 +27,9 @@
 #include <sys/types.h>
 #include <unistd.h>
 
+#include <pthread.h>
 #include <jack/jack.h>
 #include <jack/ringbuffer.h>
-#include <pthread.h>
 #include <string.h>
 
 #include "jack_rack.h"
@@ -194,7 +194,7 @@ static int jack_process (jack_nframes_t frames, void * data)
 		// Do not start returning audio until we have sent first mlt frame
 		if ( sync && i == 0 && frame_size > 0 )
 			total_size += ring_size;
-		mlt_log_debug( MLT_FILTER_SERVICE(filter), "sync %d frame_size %d ring_size %zd jack_size %zd\n", sync, frame_size, ring_size, jack_size );
+		mlt_log_debug( MLT_FILTER_SERVICE(filter), "sync %d frame_size %d ring_size %d jack_size %d\n", sync, frame_size, ring_size, jack_size );
 		
 		if ( ! sync || ( frame_size > 0  && total_size >= frame_size ) )
 		{
