@@ -111,7 +111,7 @@ mlt_consumer consumer_sdl_audio_init( mlt_profile profile, mlt_service_type type
 		mlt_properties_set_int( this->properties, "buffer", 1 );
 
 		// Default audio buffer
-		mlt_properties_set_int( this->properties, "audio_buffer", 512 );
+		mlt_properties_set_int( this->properties, "audio_buffer", 2048 );
 
 		// Ensure we don't join on a non-running object
 		this->joined = 1;
@@ -193,7 +193,9 @@ int consumer_stop( mlt_consumer parent )
 		pthread_mutex_unlock( &this->refresh_mutex );
 
 		// Cleanup the main thread
+#ifndef WIN32
 		if ( this->thread )
+#endif
 			pthread_join( this->thread, NULL );
 
 		// Unlatch the audio callback
@@ -465,7 +467,7 @@ static void *consumer_thread( void *arg )
 	int duration = 0;
 	int64_t playtime = 0;
 	struct timespec tm = { 0, 100000 };
-	int last_position = -1;
+//	int last_position = -1;
 	this->refresh_count = 0;
 
 	// Loop until told not to
@@ -534,19 +536,23 @@ static void *consumer_thread( void *arg )
 				pthread_mutex_unlock( &this->refresh_mutex );
 			}
 			else
+			{
 				mlt_frame_close( frame );
+				frame = NULL;
+			}
 
 			// Optimisation to reduce latency
-			if ( speed == 1.0 )
+			if ( frame && speed == 1.0 )
 			{
-				if ( last_position != -1 && last_position + 1 != mlt_frame_get_position( frame ) )
-					mlt_consumer_purge( consumer );
-				last_position = mlt_frame_get_position( frame );
+                // TODO: disabled due to misbehavior on parallel-consumer
+//				if ( last_position != -1 && last_position + 1 != mlt_frame_get_position( frame ) )
+//					mlt_consumer_purge( consumer );
+//				last_position = mlt_frame_get_position( frame );
 			}
 			else
 			{
 				mlt_consumer_purge( consumer );
-				last_position = -1;
+//				last_position = -1;
 			}
 		}
 	}
