@@ -195,6 +195,8 @@ static int filter_get_audio( mlt_frame frame, void **buffer, mlt_audio_format *f
 	// Get the filter properties
 	mlt_properties filter_properties = MLT_FILTER_PROPERTIES( filter );
 
+	mlt_service_lock( MLT_FILTER_SERVICE( filter ) );
+
 	// Get the properties
 	st_sample_t *input_buffer;// = mlt_properties_get_data( filter_properties, "input_buffer", NULL );
 	st_sample_t *output_buffer = mlt_properties_get_data( filter_properties, "output_buffer", NULL );
@@ -243,7 +245,7 @@ static int filter_get_audio( mlt_frame frame, void **buffer, mlt_audio_format *f
 				if ( !strncmp( name, "effect", 6 ) )
 				{
 					// Get the effect specification
-					char *value = mlt_properties_get( filter_properties, name );
+					char *value = mlt_properties_get_value( filter_properties, j );
 	
 					// Create an instance
 					if ( create_effect( filter, value, count, i, *frequency ) == 0 )
@@ -364,6 +366,8 @@ static int filter_get_audio( mlt_frame frame, void **buffer, mlt_audio_format *f
 		}
 	}
 
+	mlt_service_unlock( MLT_FILTER_SERVICE( filter ) );
+
 	return 0;
 }
 
